@@ -17,6 +17,10 @@ Backend::Backend(QObject *parent) : QObject(parent)
 {
 }
 
+void Backend::setLocale(QString locale) {
+    emit this->localeChanged(locale);
+}
+
 QString Backend::getVersion()
 {
     return QString(GetBitmaskVersion());
@@ -44,7 +48,10 @@ void Backend::donateSeen()
 
 void Backend::useLocation(QString label)
 {
-    UseLocation(toGoStr(label));
+    QByteArray loc = label.toUtf8();
+    char *c = loc.data();
+
+    UseLocation(c);
 }
 
 void Backend::useAutomaticGateway()
@@ -54,7 +61,10 @@ void Backend::useAutomaticGateway()
 
 void Backend::setTransport(QString transport)
 {
-    SetTransport(toGoStr(transport));
+    QByteArray tp = transport.toUtf8();
+    char *c = tp.data();
+
+    SetTransport(c);
 }
 
 void Backend::setUDP(bool udp)
@@ -89,7 +99,6 @@ void Backend::resetNotification(QString label)
 
 void Backend::quit()
 {
-    Quit();
     emit this->quitDone();
 }
 
