@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="et">
 <context>
     <name>About</name>
     <message>
@@ -13,19 +15,19 @@
         <translation>&lt;p&gt;Selle teenuse eest makstakse täielikult sinusuguste kasutajate poolt tulnud vabatahtlike annetustega &lt;a href=&quot;%1&quot;&gt;Palun anneta&lt;/a&gt;.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../components/About.qml" line="102"/>
+        <location filename="../components/About.qml" line="103"/>
         <source>%1 version: 
 %2</source>
-        <extracomment>%1 -&gt; application name %2 -&gt; version string</extracomment>
-        <translation type="unfinished"/>
+        <extracomment>screenshot https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/screenshots/about.png %1 -&gt; application name %2 -&gt; version string</extracomment>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Footer</name>
     <message>
-        <location filename="../components/Footer.qml" line="171"/>
+        <location filename="../components/Footer.qml" line="180"/>
         <source>Recommended</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -33,22 +35,22 @@
     <message>
         <location filename="../components/Help.qml" line="7"/>
         <source>Help</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Help.qml" line="20"/>
         <source>Troubleshooting and support</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Help.qml" line="31"/>
         <source>Report a bug</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Help.qml" line="42"/>
         <source>How to uninstall</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -56,7 +58,7 @@
     <message>
         <location filename="../components/InitErrors.qml" line="31"/>
         <source>Could not find helpers. Please check your installation</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/InitErrors.qml" line="44"/>
@@ -69,152 +71,180 @@
     <message>
         <location filename="../components/Locations.qml" line="21"/>
         <source>Select Location</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Locations.qml" line="27"/>
         <source>Automatically use best connection</source>
         <extracomment>this is in the radio button for the auto selection</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Locations.qml" line="29"/>
         <source>Manually select</source>
         <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Locations.qml" line="31"/>
         <source>Switching gateway…</source>
         <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Locations.qml" line="33"/>
         <source>Only locations with bridges</source>
         <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Locations.qml" line="65"/>
         <source>Recommended</source>
         <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>MainView</name>
     <message>
-        <location filename="../components/MainView.qml" line="33"/>
-        <location filename="../components/MainView.qml" line="53"/>
+        <location filename="../components/MainView.qml" line="43"/>
+        <location filename="../components/MainView.qml" line="66"/>
         <source>Donate</source>
         <translation>Anneta</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="46"/>
+        <location filename="../components/MainView.qml" line="59"/>
         <source>Preferences</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="60"/>
+        <location filename="../components/MainView.qml" line="73"/>
         <source>Help</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="68"/>
+        <location filename="../components/MainView.qml" line="80"/>
         <source>About</source>
         <translation>Info</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="76"/>
+        <location filename="../components/MainView.qml" line="87"/>
         <source>Quit</source>
         <translation>Välju</translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="107"/>
+        <location filename="../components/MainView.qml" line="111"/>
         <source>Please donate!</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/MainView.qml" line="121"/>
+        <location filename="../components/MainView.qml" line="125"/>
         <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Preferences</name>
     <message>
-        <location filename="../components/Preferences.qml" line="10"/>
+        <location filename="../components/Preferences.qml" line="11"/>
         <source>Preferences</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="38"/>
+        <location filename="../components/Preferences.qml" line="55"/>
         <source>Turn off the VPN to make changes</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="48"/>
+        <location filename="../components/Preferences.qml" line="71"/>
+        <source>Language</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="105"/>
         <source>Censorship circumvention</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="56"/>
+        <location filename="../components/Preferences.qml" line="113"/>
         <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="70"/>
+        <location filename="../components/Preferences.qml" line="127"/>
         <source>Use obfs4 bridges</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="96"/>
+        <location filename="../components/Preferences.qml" line="153"/>
         <source>Traffic is obfuscated to bypass blocks</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="109"/>
+        <location filename="../components/Preferences.qml" line="167"/>
         <source>Use Snowflake</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="124"/>
+        <location filename="../components/Preferences.qml" line="182"/>
         <source>Snowflake needs Tor installed in your system</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="136"/>
+        <location filename="../components/Preferences.qml" line="213"/>
+        <source>Obfs4 with KCP can help to bypass blocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="227"/>
         <source>Transport</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="144"/>
+        <location filename="../components/Preferences.qml" line="235"/>
         <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Preferences.qml" line="157"/>
+        <location filename="../components/Preferences.qml" line="248"/>
         <source>Use UDP if available</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/Preferences.qml" line="196"/>
+        <source>Use KCP if available</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Splash</name>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>There is a newer version available. </source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="100"/>
+        <location filename="../components/Splash.qml" line="101"/>
         <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Splash.qml" line="104"/>
+        <location filename="../components/Splash.qml" line="105"/>
         <source>UPGRADE NOW</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>StatusBox</name>
+    <message>
+        <location filename="../components/StatusBox.qml" line="78"/>
+        <source>This can take several minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/StatusBox.qml" line="149"/>
+        <source>Turn on</source>
+        <translation type="unfinished">Lülita sisse</translation>
     </message>
 </context>
 <context>
@@ -222,7 +252,7 @@
     <message>
         <location filename="../components/Systray.qml" line="16"/>
         <source>Checking status…</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Systray.qml" line="36"/>
@@ -233,155 +263,225 @@
         <location filename="../components/Systray.qml" line="45"/>
         <source>Hide</source>
         <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Systray.qml" line="45"/>
         <source>Show</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../components/Systray.qml" line="57"/>
         <source>Quit</source>
-        <extracomment>Part of the systray menu; quits que application</extracomment>
+        <extracomment>Part of the systray menu; quits the application</extracomment>
         <translation>Välju</translation>
     </message>
-    <message>
-        <location filename="../components/Systray.qml" line="72"/>
-        <source>Connect to</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../components/Systray.qml" line="74"/>
-        <source>Connect</source>
-        <translation type="unfinished"/>
+        <source>Connect to</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/Systray.qml" line="77"/>
+        <location filename="../components/Systray.qml" line="76"/>
+        <source>Connect</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/Systray.qml" line="79"/>
         <source>Disconnect</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>VPNState</name>
     <message>
         <location filename="../components/VPNState.qml" line="26"/>
-        <location filename="../components/VPNState.qml" line="125"/>
-        <source>Connecting</source>
-        <translation type="unfinished"/>
+        <source>Setting up</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="58"/>
+        <location filename="../components/VPNState.qml" line="51"/>
+        <location filename="../components/VPNState.qml" line="155"/>
+        <source>Connecting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="82"/>
         <source>Unsecured
 Connection</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="71"/>
+        <location filename="../components/VPNState.qml" line="98"/>
         <source>Turn on</source>
         <translation>Lülita sisse</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="91"/>
+        <location filename="../components/VPNState.qml" line="118"/>
         <source>Secured
 Connection</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="104"/>
+        <location filename="../components/VPNState.qml" line="134"/>
         <source>Turn off</source>
         <translation>Lülita välja</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="139"/>
+        <location filename="../components/VPNState.qml" line="172"/>
+        <location filename="../components/VPNState.qml" line="211"/>
         <source>Cancel</source>
         <translation>Loobu</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="223"/>
+        <location filename="../components/VPNState.qml" line="269"/>
         <source>%1 off</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 väljas</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="223"/>
+        <location filename="../components/VPNState.qml" line="269"/>
         <source>off</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="226"/>
+        <location filename="../components/VPNState.qml" line="272"/>
         <source>%1 on</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 sees</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="229"/>
+        <location filename="../components/VPNState.qml" line="275"/>
         <source>Connecting to %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>Ühendumine rakendusega %1</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="232"/>
+        <location filename="../components/VPNState.qml" line="278"/>
         <source>Stopping %1</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 peatamine</translation>
     </message>
     <message>
-        <location filename="../components/VPNState.qml" line="235"/>
+        <location filename="../components/VPNState.qml" line="281"/>
         <source>%1 blocking internet</source>
         <extracomment>%1 -&gt; application name</extracomment>
         <translation>%1 - internet blokeeritud</translation>
     </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="288"/>
+        <source>pluggable transport connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="290"/>
+        <source>connection done</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="292"/>
+        <source>doing handshake</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="294"/>
+        <source>handshake done</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="296"/>
+        <source>creating one-hop connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="298"/>
+        <source>requesting status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="300"/>
+        <source>loading status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="302"/>
+        <source>loading keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="304"/>
+        <source>requesting descriptors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="306"/>
+        <source>loading descriptors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="308"/>
+        <source>creating circuit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../components/VPNState.qml" line="310"/>
+        <source>done</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VPNSwitch</name>
     <message>
         <location filename="../qml/VPNSwitch.qml" line="10"/>
-        <source/>
-        <translation type="unfinished"/>
+        <source></source>
+        <translation></translation>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="80"/>
+        <location filename="../main.cpp" line="167"/>
         <source>: a fast and secure VPN. Powered by Bitmask.</source>
         <translation>: kiire ja turvaline VPN. Kasutatud tarkvara on Bitmask.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="87"/>
+        <location filename="../main.cpp" line="174"/>
         <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="94"/>
+        <location filename="../main.cpp" line="181"/>
         <source>Enable Web API.</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="100"/>
+        <location filename="../main.cpp" line="187"/>
         <source>Install helpers (Linux only, requires sudo).</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="106"/>
+        <location filename="../main.cpp" line="193"/>
         <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
         <translation>Kui see on teenusepakkuja poolt saadaval, siis kasuta liikluse peitmiseks teeki obfs4.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="112"/>
+        <location filename="../main.cpp" line="199"/>
+        <source>Enable autostart.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Disable autostart for the next run.</source>
-        <translation>Keela järgmisel käivitamisel automaatne käivitamine.</translation>
+        <translation type="vanished">Keela järgmisel käivitamisel automaatne käivitamine.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="117"/>
+        <location filename="../main.cpp" line="204"/>
         <source>Web API port (default: 8080)</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="119"/>
+        <location filename="../main.cpp" line="207"/>
         <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
