@@ -1,12 +1,13 @@
 package motd
 
 import (
-	"io/ioutil"
-	"log"
+	"io"
 	"net/http"
 	"os"
+	"time"
 
 	"0xacab.org/leap/bitmask-vpn/pkg/config"
+	"github.com/rs/zerolog/log"
 )
 
 const riseupMOTD = "https://static.riseup.net/vpn/motd.json"
@@ -14,36 +15,43 @@ const riseupMOTD = "https://static.riseup.net/vpn/motd.json"
 func FetchLatest() []Message {
 	empty := []Message{}
 	if os.Getenv("SKIP_MOTD") == "1" {
+		log.Info().Msg("Skipping MOTD fetch")
 		return empty
 	}
-	url := ""
-	if os.Getenv("DEBUG") == "1" {
-		url = os.Getenv("MOTD_URL")
-		if url == "" {
-			url = riseupMOTD
-		}
-	} else {
+	url := os.Getenv("MOTD_URL")
+	if url == "" {
 		switch config.Provider {
-		case "riseup.net":
+		case "riseup":
 			url = riseupMOTD
 		default:
 			return empty
 		}
 	}
-	log.Println("Fetching MOTD for", config.Provider)
+
+	log.Debug().
+		Str("url", url).
+		Msg("Fetching MOTD")
+
 	b, err := fetchURL(url)
 	if err != nil {
-		log.Println("WARN Error fetching json from", url)
+		log.Warn().Err(err).
+			Str("url", "url").
+			Msg("Could not fetch MOTD json")
 		return empty
 	}
+
 	allMsg, err := getFromJSON(b)
 	if err != nil {
-		log.Println("WARN Error parsing json from", url)
+		log.Warn().Err(err).
+			Str("msg", string(b)).
+			Msg("Could not json decode MOTD")
 		return empty
 	}
 	valid := empty[:]
 	if allMsg.Length() != 0 {
-		log.Printf("There are %d pending messages\n", allMsg.Length())
+		log.Debug().
+			Int("pendingMessages", allMsg.Length()).
+			Msg("There are pending messages")
 	}
 	for _, msg := range allMsg.Messages {
 		if msg.IsValid() {
@@ -54,10 +62,11 @@ func FetchLatest() []Message {
 }
 
 func fetchURL(url string) ([]byte, error) {
-	resp, err := http.Get(url)
+	c := http.Client{Timeout: 30 * time.Second}
+	resp, err := c.Get(url)
 	if err != nil {
 		return []byte(""), err
 	}
 	defer resp.Body.Close()
-	return ioutil.ReadAll(resp.Body)
+	return io.ReadAll(resp.Body)
 }
